"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var yogaHandler_1 = require("../yogaHandler");
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
var YogaContext = React.createContext({});
exports.YogaContextProvider = function (props) {
    var yogaRef = props.yogaRef, otherProps = __rest(props, ["yogaRef"]);
    var $subjectRef = React.useRef(new rxjs_1.Subject());
    var $recalculateRef = React.useRef(new rxjs_1.Subject());
    React.useEffect(function () {
        var instance = yogaRef.current;
        if (!instance) {
            return;
        }
        var handleYogaProps = function (newProps, instance) {
            var yogaChildren = newProps.children, yogaPropsWithoutChildren = __rest(newProps, ["children"]);
            if (instance.parent && instance.parent.type === 'GROUP') {
                yogaPropsWithoutChildren.x += instance.parent.x;
                yogaPropsWithoutChildren.y += instance.parent.y;
            }
            $subjectRef.current.next({ instance: instance, props: yogaPropsWithoutChildren });
            if (instance.children) {
                instance.children.forEach(function (child, index) {
                    handleYogaProps(newProps.children[index], child);
                });
            }
        };
        var calculate = function () {
            yogaHandler_1.yogaHandler(instance).then(function (newProps) {
                console.log('yoga mixin result', newProps);
                handleYogaProps(newProps, instance);
            });
        };
        calculate();
        var recalculationPipe = $recalculateRef.current.pipe(operators_1.debounce(function () { return rxjs_1.interval(50); }));
        recalculationPipe.subscribe(calculate);
        return function () { return recalculationPipe.unsubscribe(); };
    }, []);
    return (React.createElement(YogaContext.Provider, { value: { subject: $subjectRef.current, recalculate: $recalculateRef.current } }, props.children));
};
exports.useYogaLayout = function (props) {
    var yogaRef = props.yogaRef;
    var _a = React.useState({}), yogaProps = _a[0], setYogaProps = _a[1];
    var context = React.useContext(YogaContext);
    React.useEffect(function () {
        var instance = yogaRef.current;
        if (!context.subject) {
            return;
        }
        var subject = context.subject.pipe(operators_1.filter(function (message) { return message.instance === instance; }), operators_1.map(function (message) { return message.props; }));
        subject.subscribe(setYogaProps);
        return function () { return subject.unsubscribe(); };
    }, []);
    React.useEffect(function () {
        var instance = yogaRef.current;
        if (!instance) {
            return;
        }
        if (instance.width !== props.width || instance.height !== props.height) {
            context.recalculate && context.recalculate.next();
        }
    }, [props.width, props.height]);
    return yogaProps;
};
//# sourceMappingURL=useYogaLayout.js.map