"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PREGROUP_NODE_TYPE = 'PREGROUP';
/*
 Fake tree node that represents intention to group some elements
 Implements some methods that make fake node behave like the real one
 */
var PregroupNode = /** @class */ (function () {
    function PregroupNode(didMountHandler) {
        this.type = exports.PREGROUP_NODE_TYPE;
        this.figmaNode = null;
        this.children = [];
        // Index where group have to be placed in children list
        this.order = 0;
        // Temporarily holds plugin data until the real figma node is created
        this.scheduledPluginData = new Map();
        this.didMountHandler = didMountHandler;
    }
    PregroupNode.createFromGroupNode = function (group, didMountHandler) {
        if (group.type !== 'GROUP') {
            return null;
        }
        var pregroupNode = new PregroupNode(didMountHandler);
        pregroupNode.figmaNode = group;
        return pregroupNode;
    };
    PregroupNode.prototype.remove = function () {
        this.figmaNode.remove();
    };
    PregroupNode.prototype.appendChild = function (childNode) {
        this.children.push(childNode);
    };
    PregroupNode.prototype.getPluginData = function (key) {
        return (this.figmaNode && this.figmaNode.getPluginData(key)) || this.scheduledPluginData[key];
    };
    PregroupNode.prototype.setPluginData = function (key, value) {
        if (this.figmaNode) {
            this.figmaNode.setPluginData(key, value);
        }
        else {
            this.scheduledPluginData.set(key, value);
        }
    };
    PregroupNode.prototype.didMount = function () {
        var _this = this;
        this.didMountHandler();
        this.scheduledPluginData.forEach(function (value, key) { return _this.figmaNode.setPluginData(key, value); });
        this.scheduledPluginData.clear();
    };
    return PregroupNode;
}());
exports.PregroupNode = PregroupNode;
//# sourceMappingURL=pregroupNode.js.map