"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var transformFlexDirection = function (yoga) { return function (value) {
    switch (value) {
        case 'row':
            return yoga.FLEX_DIRECTION_ROW;
        case 'row-reverse':
            return yoga.FLEX_DIRECTION_ROW_REVERSE;
        case 'column-reverse':
            return yoga.FLEX_DIRECTION_COLUMN_REVERSE;
        default:
            return yoga.FLEX_DIRECTION_COLUMN;
    }
}; };
var transformToYogaNode = function (yoga, cache, node, yogaParent, childId) {
    var yogaNode = yoga.Node.create();
    cache.node = yogaNode;
    if (node.width && node.height && !node.children) {
        yogaNode.setWidth(node.width);
        yogaNode.setHeight(node.height);
    }
    if (node.style) {
        if (node.style.flexDirection) {
            yogaNode.setFlexDirection(transformFlexDirection(yoga)(node.style.flexDirection));
        }
        if (node.style.paddingTop) {
            yogaNode.setPadding(yoga.EDGE_TOP, node.style.paddingTop);
        }
        if (node.style.paddingBottom) {
            yogaNode.setPadding(yoga.EDGE_BOTTOM, node.style.paddingBottom);
        }
        if (node.style.paddingLeft) {
            yogaNode.setPadding(yoga.EDGE_LEFT, node.style.paddingLeft);
        }
        if (node.style.paddingRight) {
            yogaNode.setPadding(yoga.EDGE_RIGHT, node.style.paddingRight);
        }
        if (node.style.marginTop) {
            yogaNode.setMargin(yoga.EDGE_TOP, node.style.marginTop);
        }
        if (node.style.marginBottom) {
            yogaNode.setMargin(yoga.EDGE_BOTTOM, node.style.marginBottom);
        }
        if (node.style.marginLeft) {
            yogaNode.setMargin(yoga.EDGE_LEFT, node.style.marginLeft);
        }
        if (node.style.marginRight) {
            yogaNode.setMargin(yoga.EDGE_RIGHT, node.style.marginRight);
        }
        yogaNode.setAlignItems(yoga.ALIGN_FLEX_START);
        yogaNode.setJustifyContent(yoga.JUSTIFY_FLEX_START);
    }
    if (node.children) {
        node.children.forEach(function (child, id) {
            var newCache = {};
            if (!cache.children) {
                cache.children = [];
            }
            cache.children.push(newCache);
            transformToYogaNode(yoga, newCache, child, yogaNode, id);
        });
    }
    if (yogaParent) {
        yogaParent.insertChild(yogaNode, childId);
    }
    return yogaNode;
};
var transformCache = function (cache) {
    var result = cache.node.getComputedLayout();
    if (!cache.children) {
        return result;
    }
    return __assign(__assign({}, result), { children: cache.children.map(transformCache) });
};
exports.yogaWorker = function (yoga) { return function (message) {
    if (!message.value || message.value.type !== 'calculateLayout') {
        return;
    }
    var props = message.value.value;
    console.log('yogaWorker input', props);
    var cache = {};
    var yogaRoot = transformToYogaNode(yoga, cache, props, null, null);
    yogaRoot.calculateLayout(props.width, props.height, yoga.DIRECTION_LTR);
    console.log('cache', cache);
    console.log('transformCache', transformCache(cache));
    parent.postMessage({
        pluginMessage: {
            id: message.id,
            value: transformCache(cache)
        }
    }, '*');
}; };
//# sourceMappingURL=yogaWorker.js.map